@@ -62,7 +62,7 @@ setMethod('tail', signature(x='RasterStackBrick'),
 
 setMethod('head', signature(x='Spatial'), 
 	function(x, n=6L,...) {
-		if (methods::.hasSlot(x, 'data')) {
+		if (.hasSlot(x, 'data')) {
 			head(x@data, n=n, ...)
 		} else {
 			x[1,]
@@ -74,7 +74,7 @@ setMethod('head', signature(x='Spatial'),
 
 setMethod('tail', signature(x='Spatial'), 
 	function(x,  n=6L, ...) {
-		if (methods::.hasSlot(x, 'data')) {
+		if (.hasSlot(x, 'data')) {
 			tail(x@data, n=n, ...)
 		} else {
 			x[length(x),]
